3. Data model — CubicWeb 3.13.2

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Repository development »

# 3. Data model

This chapter describes how you define a schema and how to make it evolves as the time goes.

- 3.1. Yams schema
- 3.2. Defining your schema using yams
- 3.3. Metadata
- 3.4. Pre-defined entities in the library
- 3.5. Defining a Workflow

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Repository development »